@@ -8,7 +8,7 @@ use Mojo::Redis::Cursor;
 use Mojo::Redis::Database;
 use Mojo::Redis::PubSub;
 
-our $VERSION = '3.06';
+our $VERSION = '3.07';
 
 $ENV{MOJO_REDIS_URL} ||= 'redis://localhost:6379';
 
@@ -51,7 +51,7 @@ sub _connection {
   my $conn = Mojo::Redis::Connection->new(
     encoding => $self->encoding,
     protocol => $self->protocol_class->new(api => 1),
-    url      => $self->url,
+    url      => $self->url->clone,
     %args
   );
 
@@ -74,7 +74,7 @@ sub _dequeue {
 sub _enqueue {
   my ($self, $conn) = @_;
   my $queue = $self->{queue} ||= [];
-  push @$queue, $conn if $conn->is_connected;
+  push @$queue, $conn if $conn->is_connected and $conn->url eq $self->url;
   shift @$queue while @$queue > $self->max_connections;
 }
 
